# CONTENTS OF THIS FILE
---
 * Introduction
 * Installation
 * Requirements
 * Recommended modules
 * Configuration
 * Cookies
 * Customize
 * Troubleshooting
 * Maintainers

## INTRODUCTION
---
The Klaro consent manager module implements the [Klaro! consent manager utility](https://klaro.kiprotect.com/) for Drupal 8.

### The primary use case for this module is to:

- **Provide** a configurable consent / cookie manager to the site visitors giving active consent to the defined consents (apps).
- **Manipulate** scripts and other resources (based on apps) to be controlled by the [Klaro! consent manager utility](https://klaro.kiprotect.com/).
- **Satisfy** the new [eu cookie guidelines](https://edpb.europa.eu/sites/edpb/files/files/file1/edpb_guidelines_202005_consent_en.pdf) (PDF)

### Goals:
- Fully customizable, managable and translatable consents (apps).
- Fully customizable, managable and translatable purposes.
- Fully customizable and translatable texts of the consent manager.

## INSTALLATION
---
The installation of this module is like other Drupal modules.

1. Copy/upload the klaro module to the modules directory of your Drupal installation.
2. Enable the 'Klaro!' module in 'Extend': `/admin/modules`.
3. Set up user permissions: `/admin/people/permissions#module-klaro`.

## REQUIREMENTS
---
This module requires no modules outside of Drupal core.

## RECOMMENDED MODULES
---

* [Configuration Translation](https://www.drupal.org/docs/8/core/modules/config-translation) for multilingual sites.

## CONFIGURATION
---
### Backend / UI

* Link your privacy policy page: `/admin/konfig/system/klaro/settings`.
* Create a new klaro app: `/admin/konfig/system/klaro/apps` or edit an existing app: `/admin/konfig/system/klaro/apps/klaro`.
* Add a new klaro purpose: `/admin/konfig/system/klaro/purposes` or edit an existing purpose: `/admin/konfig/system/klaro/purposes/cms`.
* Configure all klaro modal texts: `/admin/konfig/system/klaro/texts`.
* Enable Klaro! `/admin/konfig/system/klaro/settings`.

## COOKIES
---
To let klaro delete cookies there are two places to provide information about them.

1. `/admin/config/system/klaro/apps/{klaro_app}`
   Inside the `Advanced` section you can provide specific cookie information about `name` (regex), `path` and `domain`
2. `/admin/config/system/klaro/settings`
   Inside the `Advanced` section you will find the `Matching cookie domains` textarea. Sometimes scripts may set cookies with dynamic cookie domains. You can add different domains here so that klaro will try to delete all cookies definied in your apps additionally with this cookie domains. So you don't need to add 30 cookie information inside your app just because a script adds several cookies just with 10 differen cookie domains.

## Customize
---
### Open the Klaro! consent manager modal

* By default if the user gave a consent and saves, the manager modal will disappear.
* If you like to provide a link or button to the user to make the manager appear again, you can use the `rel`-attribute of any clickable element to let Klaro! open the consent manager.
* Just use the `rel`-Value `open-consent-manager`.
* If there is / are already any `rel`-value(s) just extend the value e.g. `<a href="/privacy-policy" rel="nofollow open-consent-manager noindex">`.

### Inline-Scripts

If you have inline scripts in your content authored via CKEditor or any other RTE like this:
* `<script src="https://myscriptremotesource">...</script>`

and you want that Klaro! takes controll of the execution of this, you first need to decide, which consent (app) will execute this script if the visitor will give his consent.

E.g. if your klaro app ID is `foo`, then this markup of the script above should be changed to this:
* `<script type="text/plain" data-type="text/javascript" data-name="foo" data-src="https://myscriptremotesource">..."></script>`

If there are image pixels that tracks the visitor like this:
* `<img src="htps://mypixeltracker.com" width="1" height="1" />`

just change it to this:
* `<img data-src="htps://mypixeltracker.com" data-name="foo" width="1" height="1" />`

## TROUBLESHOOTING
---
- If the script- / resource **element attibutes** won't appear like the `type="text/plain"` then maybe some other module or the theme is preprocessing the script tag by stripping out this attribute.
- Issue tracker: https://www.drupal.org/project/issues/klaro?version=any_8.x-

## Maintainers
---
   * Jan Kellermann (jan kellermann) - https://www.drupal.org/u/jan-kellermann
   * Christian Kipke (ckidow) - https://www.drupal.org/u/ckidow
