<?php

namespace Drupal\klaro\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Creates the Klaro! text config form.
 */
class TextSettingsForm extends ConfigFormBase {

  /**
   * Klaro! settings for the drupal integration.
   */
  const SETTINGS = 'klaro.texts';

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'klaro_text_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['klaro'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t('Texts'),
    ];

    $form['consentModal'] = [
      '#type' => 'details',
      '#title' => $this->t('Consent modal'),
      '#group' => 'klaro',
      '#weight' => 1,
      '#tree' => TRUE,
    ];

    $form['consentModal']['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#description' => 'The titel of the consent modal.',
      '#default_value' => $config->get('consentModal.title'),
    ];

    $form['consentModal']['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Description'),
      '#description' => 'The description of the consent modal.',
      '#default_value' => $config->get('consentModal.description'),
    ];

    $form['consentModal']['privacyPolicy'] = [
      '#type' => 'details',
      '#open' => TRUE,
      '#title' => $this->t('Privacy policy'),
    ];

    $form['consentModal']['privacyPolicy']['name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Name'),
      '#default_value' => $config->get('consentModal.privacyPolicy.name'),
    ];

    $form['consentModal']['privacyPolicy']['text'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Text'),
      '#default_value' => $config->get('consentModal.privacyPolicy.text'),
      '#description' => [
        '#theme' => 'item_list',
        '#items' => [
          $this->t('You can use following placeholders: %placeholders.', [
            '%placeholders' => '{' . implode('}, {', [
              'privacyPolicy',
            ]) . '}',
          ]),
        ],
      ],
    ];

    $form['consentNotice'] = [
      '#type' => 'details',
      '#title' => $this->t('Consent notice'),
      '#group' => 'klaro',
      '#weight' => 1,
      '#tree' => TRUE,
    ];

    $form['consentNotice']['changeDescription'] = [
      '#type' => 'textfield',
      '#size' => 150,
      '#title' => $this->t('Change description'),
      '#default_value' => $config->get('consentNotice.changeDescription'),
    ];

    $form['consentNotice']['description'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Description'),
      '#default_value' => $config->get('consentNotice.description'),
      '#description' => [
        '#theme' => 'item_list',
        '#items' => [
          $this->t('You can use following placeholders: %placeholders', [
            '%placeholders' => '{' . implode('}, {', [
              'privacyPolicy',
              'purposes',
            ]) . '}',
          ]),
        ],
      ],
    ];

    $form['consentNotice']['learnMore'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Learn more link text'),
      '#default_value' => $config->get('consentNotice.learnMore'),
    ];

    // General settings.
    $form['buttons'] = [
      '#type' => 'details',
      '#title' => $this->t('Buttons'),
      '#group' => 'klaro',
      '#weight' => 2,
      '#tree' => TRUE,
    ];

    $form['buttons']['ok'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Ok button text'),
      '#default_value' => $config->get('ok'),
    ];

    $form['buttons']['save'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Save button text'),
      '#default_value' => $config->get('save'),
    ];

    $form['buttons']['decline'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Decline button text'),
      '#default_value' => $config->get('decline'),
    ];

    $form['buttons']['close'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Close button hover text'),
      '#description' => 'The description that will appear if user hovers over the close link of the modal.',
      '#default_value' => $config->get('close'),
    ];

    $form['buttons']['acceptAll'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Accept all button text'),
      '#default_value' => $config->get('acceptAll'),
    ];

    $form['buttons']['acceptSelected'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Accept selected button text'),
      '#default_value' => $config->get('acceptSelected'),
    ];

    // General settings.
    $form['app'] = [
      '#type' => 'details',
      '#title' => $this->t('App'),
      '#group' => 'klaro',
      '#weight' => 3,
      '#tree' => TRUE,
    ];

    // disableAll.
    $form['app']['disableAll'] = [
      '#type' => 'details',
      '#title' => $this->t('Disable all'),
      '#open' => TRUE,
    ];

    $form['app']['disableAll']['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => $config->get('app.disableAll.title'),
    ];

    $form['app']['disableAll']['description'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Description'),
      '#default_value' => $config->get('app.disableAll.description'),
    ];

    // Opt out.
    $form['app']['optOut'] = [
      '#type' => 'details',
      '#title' => $this->t('Opt out'),
      '#open' => TRUE,
    ];

    $form['app']['optOut']['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => $config->get('app.optOut.title'),
    ];

    $form['app']['optOut']['description'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Description'),
      '#default_value' => $config->get('app.optOut.description'),
    ];

    // Required.
    $form['app']['required'] = [
      '#type' => 'details',
      '#title' => $this->t('Required'),
      '#open' => TRUE,
    ];

    $form['app']['required']['title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Title'),
      '#default_value' => $config->get('app.required.title'),
    ];

    $form['app']['required']['description'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Description'),
      '#default_value' => $config->get('app.required.description'),
    ];

    $form['app']['purposes'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Purposes (plural)'),
      '#default_value' => $config->get('app.purposes'),
    ];

    $form['app']['purpose'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Purpose (single)'),
      '#default_value' => $config->get('app.purpose'),
    ];

    $form['poweredBy'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Powered by'),
      '#default_value' => $config->get('poweredBy'),
      '#description' => $this->t('Keep empty to remove this information from the Klaro! consent manager modal.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(static::SETTINGS)
      ->set('consentModal', $form_state->getValue('consentModal'))
      ->set('consentNotice', $form_state->getValue('consentNotice'))
      ->set('app', $form_state->getValue('app'))
      ->set('poweredBy', $form_state->getValue('poweredBy'))
      ->set('ok', $form_state->getValue(['buttons', 'ok']))
      ->set('save', $form_state->getValue(['buttons', 'save']))
      ->set('decline', $form_state->getValue(['buttons', 'decline']))
      ->set('close', $form_state->getValue(['buttons', 'close']))
      ->set('acceptAll', $form_state->getValue(['buttons', 'acceptAll']))
      ->set('acceptSelected', $form_state->getValue(['buttons', 'acceptSelected']))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
